classpath
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

more diffs


From: Matthias Pfisterer
Subject: more diffs
Date: Tue, 20 Jan 2004 23:08:32 +0100
User-agent: Mozilla/5.0 (X11; U; Linux i586; en-US; rv:1.0.0) Gecko/20020623 Debian/1.0.0-0.woody.1

Hi,

another couple of fixes (attached).

Matthias

--
Matthias Pfisterer      <mailto:address@hidden>
Reuchlinstrasse 28      phone ++49-711-62 87 12
D-70176 Stuttgart       (in Deutschland 0711-62 87 12)
GERMANY

Work like you don't need the money.
Love like you've never been hurt.
Dance like nobody is watching.

Java Sound Resources (examples, FAQ, applications):
http://www.jsresources.org/

Tritonus, the open source implementation of the Java Sound API:
http://www.tritonus.org/
--------------------------------------------------------------
Index: javax/swing/text/Position.java
===================================================================
RCS file: /cvsroot/classpath/classpath/javax/swing/text/Position.java,v
retrieving revision 1.2
diff -u -r1.2 Position.java
--- javax/swing/text/Position.java      30 Apr 2002 21:37:27 -0000      1.2
+++ javax/swing/text/Position.java      20 Jan 2004 21:24:01 -0000
@@ -40,7 +40,7 @@
 
 public interface Position
 {
-    static class Bias
+    public static final class Bias
     {
     }
     
Index: vm/reference/java/lang/VMClass.java
===================================================================
RCS file: /cvsroot/classpath/classpath/vm/reference/java/lang/VMClass.java,v
retrieving revision 1.8
diff -u -r1.8 VMClass.java
--- vm/reference/java/lang/VMClass.java 17 Apr 2003 12:32:29 -0000      1.8
+++ vm/reference/java/lang/VMClass.java 20 Jan 2004 21:57:30 -0000
@@ -81,7 +81,7 @@
 
   private void initialize(int thread) throws InterruptedException
   {
-    Error error;
+    Error error = null;
 
     /* 1 */
     synchronized (this)

reply via email to

[Prev in Thread] Current Thread [Next in Thread]
Index: java/awt/TextComponent.java
===================================================================
RCS file: /cvsroot/classpath/classpath/java/awt/TextComponent.java,v
retrieving revision 1.12
diff -u -r1.12 TextComponent.java
--- java/awt/TextComponent.java 26 Dec 2003 16:37:27 -0000      1.12
+++ java/awt/TextComponent.java 20 Jan 2004 21:53:52 -0000
@@ -235,10 +235,10 @@
   * positions are silently fixed.
   *
   * @param startSelection The new start position for the selected text.
   * @param endSelection The new end position for the selected text.
   */
 public synchronized void
-select(int selectionStart, int endSelection)
+select(int selectionStart, int selectionEnd)
 {
   if (selectionStart < 0)
     selectionStart = 0;
@@ -235,10 +235,10 @@
   *
   * @param startSelection The new start position for the selected text.
-  * @param endSelection The new end position for the selected text.
+  * @param selectionEnd The new end position for the selected text.
   */
 public synchronized void